@@ -80,8 +80,7 @@ fn on_misc_msg(msg: &str) -> MiscMessage {
                 std::thread::sleep(Duration::from_secs(3));
             }
             400 => {
-                if error_msg.starts_with("Unknown or expired symbol") {
-                    error!("Received {} from {}", msg, EXCHANGE_NAME);
+                if error_msg.starts_with("Unknown") {
                     panic!("Received {} from {}", msg, EXCHANGE_NAME);
                 } else if error_msg.starts_with("You are already subscribed to this topic") {
                     info!("Received {} from {}", msg, EXCHANGE_NAME)
@@ -122,7 +121,7 @@ impl<'a> Ticker for BitmexWSClient<'a> {
     }
 }
 
-fn to_candlestick_raw_channel(pair: &str, interval: u32) -> String {
+fn to_candlestick_raw_channel(pair: &str, interval: usize) -> String {
     let interval_str = match interval {
         60 => "1m",
         300 => "5m",
